@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import locale
 import threading
@@ -35,7 +39,7 @@ class WizardTaskError(Exception):
 
 
 class WizardTask(mforms.Box):
-    def __init__(self, owner, func, label):
+    def __init__(self, owner, func, label, accessibilityName):
         mforms.Box.__init__(self, True)
         self.set_managed()
         self.set_release_on_add()
@@ -46,6 +50,7 @@ class WizardTask(mforms.Box):
         
         self._icon = mforms.newImageBox()
         self._label = mforms.newLabel(label)
+        self._label.set_name(accessibilityName)
         
         self._enabled = True
         
@@ -157,8 +162,8 @@ class WizardTask(mforms.Box):
 
 
 class WizardThreadedTask(WizardTask):
-    def __init__(self, owner, func, label):
-        WizardTask.__init__(self, owner, func, label)
+    def __init__(self, owner, func, label, accessibilityName):
+        WizardTask.__init__(self, owner, func, label, accessibilityName)
   
         self._thread = None
         
@@ -215,6 +220,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         self._use_private_message_handling = use_private_message_handling
       
         self._description = mforms.newLabel(description or "The following tasks will now be performed. Please monitor the execution.")
+        self._description.set_name('Page Description')
         self.content.add(self._description, False, True)
         
         self._tasks_box = mforms.newBox(False)
@@ -222,7 +228,11 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         self._tasks_box.set_spacing(8)
         self.content.add(self._tasks_box, False, True)
         
+        self._after_tasks_box = mforms.newBox(False)
+        self.content.add(self._after_tasks_box, False, True)
+        
         self._status_label = mforms.newLabel("Click [Next >] to execute.")
+        self._status_label.set_name("Next Information")
         self.content.add(self._status_label, False, True)
         
         self._progress = mforms.newProgressBar()
@@ -230,6 +240,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         self._progress.show(False)
         
         self._detail_label = mforms.newLabel("")
+        self._detail_label.set_name('Details')
         self.content.add(self._detail_label, False, True)
 
         self._timer = None
@@ -240,11 +251,12 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         
         self._log_box = mforms.newPanel(mforms.TitledBoxPanel)
         self._log_box.set_title("Message Log")
-        self._log_box.set_padding(12)
+        self._log_box.set_name("Message Log")
         
         self._log_text = mforms.newTextBox(mforms.VerticalScrollBar)
-        self._log_text.set_name('WizardProgressLogText')
+        self._log_text.set_name('Wizard Progress Log Text')
         self._log_text.set_read_only(True)
+        self._log_text.set_padding(16)
         self._log_box.add(self._log_text)
         self._log_box.show(False)
         self.content.add_end(self._log_box, True, True)
@@ -268,7 +280,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
     def format_exception_text(self, e):
         return str(e)    
         
-    def add_task(self, func, label):
+    def add_task(self, func, label, accessibilityName):
         """ Add a task to be executed from the main thread. The callback must be as in
           callback(progress), where progress is a function to be optionally executed to
           report progress. 
@@ -277,13 +289,13 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
           by the user. If an error occurs during the execution of the task, an exception must 
           be raised.
         """
-        wtask = WizardTask(self, func, label)
+        wtask = WizardTask(self, func, label, accessibilityName)
         self._tasks.append(wtask)
         self._tasks_box.add(wtask, False, True)
         return wtask
     
     
-    def add_threaded_task(self, func, label):
+    def add_threaded_task(self, func, label, accessibilityName):
         """ Add a task to be executed from a worker thread. The callback must be as in
           callback(). Progress information must be reported using grt.send_progress()
            
@@ -291,7 +303,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
           by the user. If an error occurs during the execution of the task, an exception must 
           be raised.
         """
-        wtask = WizardThreadedTask(self, func, label)
+        wtask = WizardThreadedTask(self, func, label, accessibilityName)
         self._tasks.append(wtask)
         self._tasks_box.add(wtask, False, True)
         return wtask
@@ -317,6 +329,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         else:
             self.advanced_button.set_text("Show Logs")
         self._log_box.show(self._showing_logs)
+        self.relayout()
     
     def go_cancel(self):
         self._cancel_requested = True
@@ -362,15 +375,15 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         self._log_queue.append(("OUTPUT", msg, ""))
 
     def send_info(self, msg):
-        grt.log_debug("Wizard", msg)
+        grt.log_debug("Wizard", msg + "\n")
         self._handle_task_output("INFO", msg, "")
         
     def send_error(self, msg):
-        grt.log_debug("Wizard", "ERROR: "+msg)
+        grt.log_debug("Wizard", "ERROR: %s\n" % msg )
         self._handle_task_output("ERROR", msg, "")
         
     def send_warning(self, msg):
-        grt.log_debug("Wizard", "WARNING: "+msg)
+        grt.log_debug("Wizard", "WARNING: %s\n" % msg )
         self._handle_task_output("WARNING", msg, "")
 
     def send_progress(self, pct, msg):
@@ -394,6 +407,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
             grt.push_message_handler(self._handle_task_output)
         self.send_info("Starting...")
         self._timer = mforms.Utilities.add_timeout(0.1, self.update_status)
+        self.relayout()
         
     def resume(self):
         self._progress.show()
@@ -408,6 +422,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
 
         self._tasks_held = False
         self._timer = mforms.Utilities.add_timeout(0.1, self.update_status)
+        self.relayout()
 
         
     def tasks_finished(self):
@@ -430,6 +445,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         self.cancel_button.set_enabled(True)
 
         self._tasks_held = True
+        self.relayout()
 
 
 
@@ -462,6 +478,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
             self.tasks_failed(False)
         else:
             self.tasks_finished()
+        self.relayout()
 
 
     def _failed(self):
@@ -485,6 +502,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
             self.go_advanced()
 
         self.tasks_failed(False)
+        self.relayout()
         
 
     def _cancelled(self):
@@ -505,6 +523,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         self._detail_label.set_text("Cancelled by user.")
 
         self.tasks_failed(True)
+        self.relayout()
 
 
     def _flush_messages(self):
@@ -559,7 +578,7 @@ class WizardProgressPage(wizard_page_widget.WizardPage):
         elif self._warnings > 0:
             ret_val = "There were warnings during execution; please review log messages.\nClick [Next >] to continue if you think they are not important."
         else:
-            ret_val = self.final_message() + "\nClick [Next >] to continue."
+            ret_val = self.final_message() + " Click [Next >] to continue."
 
         return ret_val
 
